Crate rldb

source ·
RLDB (Rusty Learning Dynamo Database) is an educational project that provides a Rust implementation of the Amazon dynamo paper. This project aims to help developers and students understand the principles behind distributed key value data stores.

Modules

  • Module that contains the Client API for all public commands implemented by rldb.
  • Module that contains algorithms related to cluster mode
  • Module that contains all commands implemented by rldb.
  • This module defines client/user visible errors that can be returned by rldb.
  • Module that contains the abstraction connecting Storage and ClusterState into a single interface.
  • A TCP based server that receives incoming requests and dispatches Command